@@ -1,7 +1,7 @@
 package Bencher::Scenario::GetoptLongComplete::Completion;
 
-our $DATE = '2016-01-08'; # DATE
-our $VERSION = '0.02'; # VERSION
+our $DATE = '2017-01-25'; # DATE
+our $VERSION = '0.03'; # VERSION
 
 use 5.010001;
 use strict;
@@ -92,7 +92,7 @@ Bencher::Scenario::GetoptLongComplete::Completion - Benchmark completion respons
 
 =head1 VERSION
 
-This document describes version 0.02 of Bencher::Scenario::GetoptLongComplete::Completion (from Perl distribution Bencher-Scenarios-GetoptLongComplete), released on 2016-01-08.
+This document describes version 0.03 of Bencher::Scenario::GetoptLongComplete::Completion (from Perl distribution Bencher-Scenarios-GetoptLongComplete), released on 2017-01-25.
 
 =head1 SYNOPSIS
 
@@ -102,6 +102,10 @@ To run benchmark with default option:
 
 For more options (dump scenario, list/include/exclude/add participants, list/include/exclude/add datasets, etc), see L<bencher> or run C<bencher --help>.
 
+=head1 DESCRIPTION
+
+Packaging a benchmark script as a Bencher scenario makes it convenient to include/exclude/add participants/datasets (either via CLI or Perl code), send the result to a central repository, among others . See L<Bencher> and L<bencher> (CLI) for more details.
+
 =head1 BENCHMARK PARTICIPANTS
 
 =over
@@ -110,20 +114,20 @@ For more options (dump scenario, list/include/exclude/add participants, list/inc
 
 =head1 SAMPLE BENCHMARK RESULTS
 
-Run on: perl: I<< v5.22.0 >>, CPU: I<< Intel(R) Core(TM) i5-2400 CPU @ 3.10GHz (4 cores) >>, OS: I<< GNU/Linux Debian version 8.0 >>, OS kernel: I<< Linux version 3.16.0-4-amd64 >>.
+Run on: perl: I<< v5.24.0 >>, CPU: I<< Intel(R) Core(TM) M-5Y71 CPU @ 1.20GHz (2 cores) >>, OS: I<< GNU/Linux LinuxMint version 17.3 >>, OS kernel: I<< Linux version 3.19.0-32-generic >>.
 
-Benchmark with default option:
+Benchmark with default options (C<< bencher -m GetoptLongComplete::Completion >>):
 
- +-----+---------+------+--------+---------+---------+
- | seq | name    | rate | time   | errors  | samples |
- +-----+---------+------+--------+---------+---------+
- | 0   | optname | 55   | 18ms   | 0.00013 | 22      |
- | 1   | optval  | 56.3 | 17.8ms | 2.6e-05 | 20      |
- +-----+---------+------+--------+---------+---------+
+ #table1#
+ +-------------+-----------+-----------+------------+---------+---------+
+ | participant | rate (/s) | time (ms) | vs_slowest |  errors | samples |
+ +-------------+-----------+-----------+------------+---------+---------+
+ | optval      |        49 |        20 |          1 | 5.1e-05 |      21 |
+ | optname     |        52 |        19 |          1 | 7.9e-05 |      20 |
+ +-------------+-----------+-----------+------------+---------+---------+
 
-=head1 DESCRIPTION
 
-Packaging a benchmark script as a Bencher scenario makes it convenient to include/exclude/add participants/datasets (either via CLI or Perl code), send the result to a central repository, among others . See L<Bencher> and L<bencher> (CLI) for more details.
+To display as an interactive HTML table on a browser, you can add option C<--format html+datatables>.
 
 =head1 HOMEPAGE
 
@@ -147,7 +151,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2016 by perlancar@cpan.org.
+This software is copyright (c) 2017 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
